@@ -22,7 +22,7 @@ find_java_runtime
 
 # Request jython and friends.
 # (I'd like to have it used only if found, but this does not work yet: as we build-dep on jython, jh_build adds it to the depends)
-find_jars jython jruby antlr3-runtime-3.2 asm3
+find_jars jython jruby antlr3-runtime-3.2
 # jython fails with antlr3-runtime-3.5 (see #796933)
 
 # For some reason, some people need these jar to be manually loaded. That's annoying, they should be picked automatically instead.
